@@ -5,8 +5,8 @@ import (
 	"testing"
 	"time"
 
-	testinghelpers "github.com/open-cluster-management/registration/pkg/helpers/testing"
-	"github.com/open-cluster-management/registration/pkg/hub/user"
+	testinghelpers "open-cluster-management.io/registration/pkg/helpers/testing"
+	"open-cluster-management.io/registration/pkg/hub/user"
 
 	"github.com/openshift/library-go/pkg/operator/events/eventstesting"
 
