@@ -5,9 +5,9 @@ import (
 	"fmt"
 	"reflect"
 
-	clusterv1listers "github.com/open-cluster-management/api/client/cluster/listers/cluster/v1"
-	worklister "github.com/open-cluster-management/api/client/work/listers/work/v1"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
+	clusterv1listers "open-cluster-management.io/api/client/cluster/listers/cluster/v1"
+	worklister "open-cluster-management.io/api/client/work/listers/work/v1"
+	clusterv1 "open-cluster-management.io/api/cluster/v1"
 
 	"github.com/openshift/library-go/pkg/controller/factory"
 	"github.com/openshift/library-go/pkg/operator/events"
@@ -109,7 +109,7 @@ func (m *finalizeController) syncRoleAndRoleBinding(ctx context.Context, control
 		return nil
 	}
 
-	// There are twp possible cases that we need to remove finalizers on role/rolebindings based on
+	// There are two possible cases that we need to remove finalizers on role/rolebindings based on
 	// clean of manifestworks.
 	// 1. The namespace is finalizing.
 	// 2. The cluster is finalizing but namespace fails to be deleted.
